@@ -484,14 +484,14 @@ class RandomCosineLR(AdjustLRCallbackBase):
 
 
 
-def random_cosine_lr( min_lr=1e-8,period=100,cosine_weight=0.2,noise_weight=0.3, random_start_epoch=3,**kwargs):
+def random_cosine_lr(max_lr=None, min_lr=1e-8,period=100,cosine_weight=0.2,noise_weight=0.3, random_start_epoch=3,**kwargs):
    return RandomCosineLR(period=period,cosine_weight=cosine_weight,noise_weight=noise_weight, random_start_epoch=random_start_epoch,**kwargs)
 
 
 class CosineLR(AdjustLRCallbackBase):
-    def __init__(self, min_lr=1e-8,period=1000,**kwargs):
+    def __init__(self, max_lr=None, min_lr=1e-8,period=1000,**kwargs):
         super(CosineLR, self).__init__()
-        self.max_lr = None
+        self.max_lr = max_lr
         self.min_lr = min_lr
         self.period=period
         self.T_max=period/2
