@@ -9,6 +9,7 @@ import time
 import matplotlib.pyplot as plt
 import numpy as np
 import torch
+from trident.backend.tensorspec import ObjectType
 
 from trident import context
 from trident.backend.common import *
@@ -280,45 +281,49 @@ class SegTileImageCallback(VisualizationCallbackBase):
         background = np.reshape(to_numpy(self.background), new_shape)
         tile_images_list = []
         input = None
-        target = None
+        mask = None
         output = None
         is_label_mask = self.is_label_mask
         data_feed = training_context['data_feed']
         data = training_context['train_data']
         model = training_context['current_model']
+        dataprovider = enforce_singleton(ctx.get_data_provider())
+        if self.reverse_image_transform is None:
+            if len(ctx.get_data_provider()) == 1:
+                self.reverse_image_transform = dataprovider.reverse_image_transform
+                self.reverse_image_transform_funcs = dataprovider.reverse_image_transform_funcs
 
-        # if len(data) >= 3:
-        for data_key in data.key_list:
-            if data_key == data_feed[model.signature.inputs.key_list[0]]:
-                input = data[data_feed[model.signature.inputs.key_list[0]]]
-                model.eval()
-                if is_label_mask:
-                    output = to_numpy(argmax(model(input), axis=axis))
-                else:
-                    output = to_numpy(expand_dims(cast(argmax(model(input), axis=axis), input.dtype), axis=axis))
-
-                model.train()
-
-            # elif data_key == data_feed[model.signature.outputs.key_list[0]]:
-            #     output = data[data_feed[model.signature.outputs.key_list[0]]]
-            #     if output.max() < 0:
-            #         output = exp(output)
-
-            elif (
-                    'target' in data_key or 'label' in data_key or 'mask' in data_key) and not 'output' in data_key and data_key in data_feed.value_list:
-                target = to_numpy(data[data_key])
-        output_arr = None
-        if 'alpha' not in data:
-            output_arr = output.copy()
-            if is_label_mask:
-                target = label2color(target, self.palette)
-                output = label2color(output, self.palette)
-        else:
+        input = to_numpy(data[data_feed[model.signature.inputs.key_list[0]]])
+        if 'tensor' in model.__class__.__name__.lower():
+            output = to_numpy(model.clone())
+        elif isinstance(model, Layer):
+            output = to_numpy(data[data_feed[model.signature.outputs.key_list[0]]].copy())
+        mask_type=None
+        output_arr=output.copy()
+        if isinstance(dataprovider.traindata.label, MaskDataset):
+            mask_type=dataprovider.traindata.label.object_type
+            mask = to_numpy(data[dataprovider.traindata.label.symbol])
+        elif isinstance(dataprovider.traindata.label, ZipDataset):
+            for ds in dataprovider.traindata.label._datasets:
+                if isinstance(ds, MaskDataset):
+                    mask_type =ds.object_type
+                    mask = to_numpy(data[ds.symbol])
+        if mask_type==ObjectType.label_mask:
+            mask = label2color(mask, self.palette)
+            if ndim(output)==4:
+                output=argmax(output,1)
+            output_arr = label2color(output, self.palette)
+        elif  mask_type==ObjectType.binary_mask:
+            if ndim(output)==4:
+                output=argmax(output,1)
+            output_arr=output
+        elif mask_type == ObjectType.alpha_mask:
             if get_backend() == 'tensorflow':
-                output = output[:, :, :, 1:2] * argmax(output, axis)
+                output_arr = output[:, :, :, 1:2] * argmax(output, axis)
             else:
-                output = (output[:, 1:2, :, :] * argmax(output, axis)).transpose(0, 2, 3, 1)
-            target = to_numpy(data['alpha'])
+                output_arr = (output[:, 1:2, :, :] * argmax(output, axis)).transpose(0, 2, 3, 1)
+
+
 
         input_arr = []
         input = to_numpy(input)
@@ -329,16 +334,21 @@ class SegTileImageCallback(VisualizationCallbackBase):
         tile_images_list.append(input_arr)
 
         if is_label_mask:
-            tile_images_list.append(target)
+            tile_images_list.append(mask)
             tile_images_list.append(output)
         else:
-            target_arr = target
+            target_arr = mask
 
-            if len(target.shape) < len(int_shape(input)):
+            if len(mask.shape) < len(int_shape(input)):
                 if get_backend() == 'tensorflow':
-                    target_arr = np.expand_dims(target, -1)
+                    target_arr = np.expand_dims(mask, -1)
                 else:
-                    target_arr = np.expand_dims(target, axis=axis)
+                    target_arr = np.expand_dims(mask, axis=axis)
+            if len(output_arr.shape) < len(int_shape(input)):
+                if get_backend() == 'tensorflow':
+                    output_arr = np.expand_dims(output_arr, -1)
+                else:
+                    output_arr = np.expand_dims(output_arr, axis=axis)
 
             if 'alpha' not in data:
                 target_arr[target_arr > 0] = 1
