@@ -434,9 +434,12 @@ class MaskDataset(Dataset):
         if isinstance(mask, str):
             if self.object_type == ObjectType.binary_mask:
                 mask = file2array(mask, flag=cv2.IMREAD_GRAYSCALE)
-                mask[mask > 0] = 1
-                mask[mask <= 0] = 0
+                if mask.max()>1:
+                    mask=mask/mask.max()
+                mask[mask >= 0.5] = 1
+                mask[mask< 0.5] = 0
                 mask.astype(np.int64)
+
             elif self.object_type == ObjectType.alpha_mask:
                 mask = file2array(mask, flag=cv2.IMREAD_GRAYSCALE)
             elif self.object_type == ObjectType.label_mask:
@@ -857,8 +860,12 @@ class TextSequenceDataset(Dataset):
     def __init__(self, corpus=None, is_onehot=False, sequence_offset=0, storage_unit='section',section_delimiter='\n\n', stopwords=None, sequence_length: int = 64, sequence_start_at='random',
                  include_segment_ids=False,include_mask_ids=False,object_type=ObjectType.corpus, symbol=None, **kwargs):
         super().__init__(None,symbol=symbol, object_type=object_type, **kwargs)
+        valid_sequence_start_at = ['random', 'slide', 'follow_up', 'section_start']
         self.sequence_length = sequence_length
-        self.sequence_start_at = sequence_start_at
+        if sequence_start_at in valid_sequence_start_at:
+            self.sequence_start_at = sequence_start_at
+        else:
+            self.sequence_start_at ='random'
         self.length_index = OrderedDict()
         self.vocabs_frequency = OrderedDict()
         self.transform_funcs = []
@@ -942,7 +949,7 @@ class TextSequenceDataset(Dataset):
     def __getitem__(self, index: int):
         sequencetext = None
         if isinstance(self.sequence_offset, int):
-            if self.sequence_start_at == 'random':
+            if self.sequence_start_at in [ 'random','word_start']:
                 for k,v in self.length_index.item_list:
                     if v>index:
                         last_v = self.length_index[k - 1] if k>0 else 0
@@ -1249,7 +1256,7 @@ class Iterator(object):
 
     def get_datasets(self):
         datasets = []
-        if self._data and isinstance(self._data, Dataset) and not isinstance(self._data, ZipDataset) and len(self._data) > 0:
+        if self._data is not None and isinstance(self._data, Dataset) and not isinstance(self._data, ZipDataset) and len(self._data) > 0:
             datasets.append(self._data)
         elif self._data and isinstance(self._data, ZipDataset):
             for ds in self._data.items:
