@@ -642,7 +642,7 @@ class RandomTransformAffine(VisionTransform):
             elif self.border_mode=='zero':
                 _borderValue=(0,0,0)
 
-            image = cv2.warpAffine(image.copy(), mat_img, dsize=(width, height), borderMode=_borderMode,borderValue=_borderValue )  # , borderMode=cv2.BORDER_REPLICATE
+            image = cv2.warpAffine(image.copy(), mat_img, dsize=(width, height), borderMode=_borderMode,borderValue=_borderValue,flags=cv2.INTER_LANCZOS4 )  # , borderMode=cv2.BORDER_REPLICATE
             if is_flip:
                 return image[:, ::-1]
             else:
@@ -677,7 +677,9 @@ class RandomTransformAffine(VisionTransform):
             mask_dtype = mask.dtype
             mask = mask.astype(np.float32)
 
-            mask = cv2.warpAffine(mask, mat_img, (width, height), borderMode=cv2.BORDER_CONSTANT, borderValue=(0, 0, 0))  # , borderMode=cv2.BORDER_REPLICATE
+            mask = cv2.warpAffine(mask, mat_img, (width, height), borderMode=cv2.BORDER_CONSTANT, borderValue=(0, 0, 0),flags=cv2.INTER_NEAREST)  # , borderMode=cv2.BORDER_REPLICATE
+            mask[mask>=0.5]=1
+            mask[mask < 0.5] =0
             mask = mask.astype(mask_dtype)
             if is_flip:
                 return mask[:, ::-1]
