@@ -228,7 +228,7 @@ class _ClassificationLoss(Loss):
             self.need_target_onehot = True
         if target.dtype == str2dtype('long'):
             self.is_target_onehot = False
-        elif target.dtype != str2dtype('long') and (target.min() >= 0 and target.max() <= 1 and abs(output_exp.sum(-1).mean() - 1) < 1e-4):
+        elif target.dtype != str2dtype('long') and (target.min() >= 0 and target.max() <= 1 and abs(target.sum(-1).mean() - 1) < 1e-4):
             target = clip(target, min=1e-8, max=1 - 1e-8)
             self.is_target_onehot = True
 
@@ -947,7 +947,7 @@ class MSELoss(_PairwiseLoss):
 
     """
 
-    def __init__(self, axis=-1, reduction='sum', name='MSELoss'):
+    def __init__(self, axis=-1, reduction='mean', name='MSELoss'):
         super().__init__(axis, reduction, name)
         self._built = True
 
@@ -966,7 +966,7 @@ class MSELoss(_PairwiseLoss):
 
         # num_present = tf.reduce_sum(math_ops.cast(array_ops.size(output, name='num_elements'), dtype=output.dtype),name='reduce_sum')
         with self._name_scope:
-            return tf.nn.l2_loss(output - target)
+            return (output - target)**2
         # return math_ops.div_no_nan(tf.nn.l2_loss(output-target), math_ops.cast(tf.shape(output)[0], dtype=output.dtype), name='value')
 
 
@@ -1075,6 +1075,9 @@ class EdgeLoss(_PairwiseLoss):
         super(EdgeLoss, self).__init__()
 
     def first_order(self, x, axis=2):
+        if ndim(x)==3:
+            shp=list(int_shape(x))
+            x=x.reshape((shp[0],int(math.sqrt(float(shp[1]))),int(math.sqrt(float(shp[1]))),shp[-1]))
         h, w = x.shape[1:3]
         if axis == 1:
             return tf.math.abs((x[:, :h - 1, :w - 1, :] - x[:, 1:, :w - 1, :]))
@@ -1083,7 +1086,7 @@ class EdgeLoss(_PairwiseLoss):
         else:
             return None
 
-    def call(self, target, output):
+    def calculate_loss(self, output, target, **kwargs):
         with self._name_scope:
             loss1 = tf.reduce_mean(tf.math.square(self.first_order(output, 1) - self.first_order(target, 1)))
             loss2 = tf.reduce_mean(tf.math.square(self.first_order(output, 2) - self.first_order(target, 2)))
